@@ -1,6 +1,6 @@
 package Config::Find;
 
-our $VERSION = '0.25';
+our $VERSION = '0.27';
 
 use strict;
 use warnings;
@@ -11,48 +11,42 @@ use Carp;
 our @ISA;
 BEGIN {
     if ($^O=~/Win32/) {
-	require Win32;
-	my $OS=uc Win32::GetOSName();
-	
-	if ($OS=~/^WIN95/) {
-	    require Config::Find::Win95;
-	    @ISA=qw(Config::Find::Win95);
-	}
-	elsif ($OS=~/^WIN98/) {
-	    require Config::Find::Win98;
-	    @ISA=qw(Config::Find::Win98);
-	}
-	elsif ($OS=~/^WINME/) {
-	    require Config::Find::WinME;
-	    @ISA=qw(Config::Find::WinME);
-	}
-	elsif ($OS=~/^WINNT/) {
-	    require Config::Find::WinNT;
-	    @ISA=qw(Config::Find::WinNT);
-	}
-	elsif ($OS=~/^WIN2000/) {
-	    require Config::Find::Win2k;
-	    @ISA=qw(Config::Find::Win2k);
-	}
-	elsif ($OS=~/^WIN2003/) {
-	    require Config::Find::Win2k3;
-	    @ISA=qw(Config::Find::Win2k3);
-	}
-	elsif ($OS=~/^WINXP/) {
-	    require Config::Find::WinXP;
-	    @ISA=qw(Config::Find::WinXP);
-	}
-	elsif ($OS=~/^WINCE/) {
-	    require Config::Find::WinCE;
-	    @ISA=qw(Config::Find::WinCE);
-	}
-	else {
-	    croak "Unknow MSWin32 OS '$OS'";
-	}
-    }
-    else {
-	require Config::Find::Unix;
-	@ISA=qw(Config::Find::Unix);
+        require Win32;
+        my $OS = uc Win32::GetOSName();
+        
+        if ($OS=~/^WIN95/) {
+            require Config::Find::Win95;
+            @ISA=qw(Config::Find::Win95);
+        } elsif ($OS=~/^WIN98/) {
+            require Config::Find::Win98;
+            @ISA=qw(Config::Find::Win98);
+        } elsif ($OS=~/^WINME/) {
+            require Config::Find::WinME;
+            @ISA=qw(Config::Find::WinME);
+        } elsif ($OS=~/^WINNT/) {
+            require Config::Find::WinNT;
+            @ISA=qw(Config::Find::WinNT);
+        } elsif ($OS=~/^WIN2000/) {
+            require Config::Find::Win2k;
+            @ISA=qw(Config::Find::Win2k);
+        } elsif ($OS=~/^WIN2003/) {
+            require Config::Find::Win2k3;
+            @ISA=qw(Config::Find::Win2k3);
+        } elsif ($OS=~/^WINXP/) {
+            require Config::Find::WinXP;
+            @ISA=qw(Config::Find::WinXP);
+        } elsif ($OS=~/^WINCE/) {
+            require Config::Find::WinCE;
+            @ISA=qw(Config::Find::WinCE);
+        } elsif ($OS=~/^WIN7/) {
+            require Config::Find::Win7;
+            @ISA=qw(Config::Find::Win7);
+        } else {
+            croak "Unknow MSWin32 OS '$OS'";
+        }
+    } else {
+        require Config::Find::Unix;
+        @ISA=qw(Config::Find::Unix);
     }
 }
 
@@ -60,7 +54,7 @@ sub find {
     my $class=shift;
     my ($write, $global, $fn, @names)=$class->parse_opts(@_);
     if (defined $fn) {
-      return ($write or -f $fn) ? $fn : undef;
+        return ($write or -f $fn) ? $fn : undef;
     }
     $class->_find($write, $global, @names);
 }
@@ -75,8 +69,7 @@ sub open {
 sub install {
     my $class=shift;
     my $orig=shift;
-    my ($write, $global, $fn, @names)=$class->parse_opts( mode => 'w',
-							  @_);
+    my ($write, $global, $fn, @names)=$class->parse_opts( mode => 'w', @_);
     defined($fn) or $fn=$class->_find($write, $global, @names);
     $class->_install($orig, $write, $global, $fn);
 }
@@ -86,46 +79,45 @@ sub parse_opts {
     my $fn=$opts{file};
     my @names;
     if (exists $opts{name}) {
-	@names=$opts{name};
-    }
-    elsif (exists $opts{names}) {
-	UNIVERSAL::isa($opts{names}, 'ARRAY')
-	    or croak "invalid argument for 'names', expecting an array ref";
-	@names=@{$opts{names}}
-    }
-    else {
-	@names=$class->guess_script_name();
+        @names=$opts{name};
+    } elsif (exists $opts{names}) {
+        UNIVERSAL::isa($opts{names}, 'ARRAY')
+            or croak "invalid argument for 'names', expecting an array ref";
+        @names=@{$opts{names}}
+    } else {
+        @names=$class->guess_script_name();
     }
+    
     my $write;
     if (exists $opts{mode}) {
-	if ($opts{mode}=~/^r(ead)?$/i) {
-	    # yes, do nothing!
-	}
-	elsif ($opts{mode}=~/w(rite)?$/i) {
-	    $write=1;
-	}
-	else {
-	    croak "invalid option mode => '$opts{mode}'";
-	}
+        if ($opts{mode}=~/^r(ead)?$/i) {
+            # yes, do nothing!
+        } elsif ($opts{mode}=~/w(rite)?$/i) {
+            $write=1;
+        } else {
+            croak "invalid option mode => '$opts{mode}'";
+        }
     }
+
     my $global;
     if (exists $opts{scope}) {
-	if ($opts{scope}=~/^u(ser)?$/i) {
-	    # yes, do nothing!
-	}
-	elsif ($opts{scope}=~/g(lobal)?$/i) {
-	    $global=1;
-	}
-	else {
-	    croak "invalid option scope => '$opts{scope}'";
-	}
+        if ($opts{scope}=~/^u(ser)?$/i) {
+            # yes, do nothing!
+        } elsif ($opts{scope}=~/g(lobal)?$/i) {
+            $global=1;
+        } else {
+            croak "invalid option scope => '$opts{scope}'";
+        }
     }
     return ($write, $global, $fn, @names)
 }
 
 1;
+
 __END__
 
+=encoding utf-8
+
 =head1 NAME
 
 Config::Find - Find configuration files in the native OS fashion
@@ -157,13 +149,13 @@ Config::Find - Find configuration files in the native OS fashion
 
 =head1 ABSTRACT
 
-Config::Find searchs for configuration files using OS dependant
+Config::Find searches for configuration files using OS dependant
 heuristics.
 
 =head1 DESCRIPTION
 
 Every OS has different rules for configuration files placement, this
-module allows to easily find and create your app configuration files
+module allows one to easily find and create your app configuration files
 following those rules.
 
 Config::Find references configuration files by the application name or
@@ -273,10 +265,13 @@ OS.
 
 L<Config::Auto> give me the idea for this module.
 
+=head1 AUTHOR
+
+Salvador Fandio Garca, E<lt>sfandino@yahoo.comE<gt>
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003-2008 by Salvador FandiE<ntilde>o GarcE<iacute>a
-(sfandino@yahoo.com)
+Copyright 2003-2015 by Salvador Fandio Garca (sfandino@yahoo.com)
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
