@@ -1,6 +1,6 @@
 package Config::Find::Win2k3;
 
-our $VERSION = '0.01';
+our $VERSION = '0.27';
 
 use strict;
 use warnings;
@@ -12,13 +12,15 @@ our @ISA = qw(Config::Find::WinAny);
 1;
 __END__
 
+=encoding utf-8
+
 =head1 NAME
 
 Config::Find::Win2k - Win2k idiosyncrasies for Config::Find
 
 =head1 SYNOPSIS
 
-  # don't use Config::Find::Win2k3;
+  # don't use Config::Find::Win2k3 directly
   use Config::Find;
 
 =head1 ABSTRACT
@@ -27,14 +29,8 @@ Implements Win2003 specific features for Config::Find
 
 =head1 DESCRIPTION
 
-Stub documentation for Config::Find::Win2003, created by h2xs.
-
-
-=head2 EXPORT
-
-None by default.
-
-
+Contains any idiosyncrasies found within Win2003, that do not apply to the 
+standard Win32 base.
 
 =head1 SEE ALSO
 
@@ -42,11 +38,11 @@ L<Config::Find>, L<Config::Find::WinAny>, L<Config::Find::Any>
 
 =head1 AUTHOR
 
-Salvador Fandio, E<lt>sfandino@yahoo.comE<gt>
+Salvador Fandio Garca, E<lt>sfandino@yahoo.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003 by Salvador Fandio
+Copyright 2003-2015 by Salvador Fandio Garca (sfandino@yahoo.com)
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
