@@ -1,15 +1,16 @@
 package Config::Find::WinAny;
 
-our $VERSION = '0.17';
+our $VERSION = '0.27';
 
 use strict;
 use warnings;
 
 use Carp;
-
 use Config::Find::Any;
-use Win32 qw(CSIDL_LOCAL_APPDATA
-	     CSIDL_APPDATA);
+use Win32 qw(
+        CSIDL_LOCAL_APPDATA
+        CSIDL_APPDATA
+        CSIDL_DESKTOPDIRECTORY);
 
 our @ISA = qw(Config::Find::Any);
 
@@ -17,38 +18,39 @@ sub app_dir {
     my ($class, $name)=@_;
 
     $name=$class->guess_script_name
-	unless defined $name;
+    unless defined $name;
 
     my $ename = uc($name).'_HOME';
-    if (exists $ENV{$ename}) {
-	return $ENV{$ename}
-    }
+    return $ENV{$ename} if (exists $ENV{$ename});
     $class->guess_script_dir;
 }
 
 my $winlocalappdir=Win32::GetFolderPath(CSIDL_LOCAL_APPDATA);
 my $winappdir=Win32::GetFolderPath(CSIDL_APPDATA);
 
+my $windesktop=Win32::GetFolderPath(CSIDL_DESKTOPDIRECTORY);
+
+if (defined $windesktop and $windesktop ne '') {
+    undef $winlocalappdir   if (defined($winlocalappdir) and index($winlocalappdir, $windesktop) == 0);
+    undef $winappdir        if (defined($winappdir)      and index($winappdir, $windesktop) == 0);
+}
+
 sub app_user_dir {
     my ($class, $name)=@_;
     return ( (defined $winlocalappdir) && ($winlocalappdir ne "") ? $winlocalappdir :
-	     (defined $winappdir) && ($winappdir ne "") ? $winappdir :
-	     File::Spec->catdir($class->app_dir($name),
-				'Users',
-				$class->my_getlogin));
+         (defined $winappdir) && ($winappdir ne "") ? $winappdir :
+         File::Spec->catdir($class->app_dir($name),
+                'Users',
+                $class->my_getlogin));
 }
 
 sub system_temp {
     my $class=shift;
 
-    return $ENV{TEMP}
-	if defined $ENV{TEMP};
+    return $ENV{TEMP}   if defined $ENV{TEMP};
+    return $ENV{TMP}    if defined $ENV{TMP};
 
-    return $ENV{TMP}
-	if defined $ENV{TMP};
-
-    return File::Spec->catfile($ENV{windir}, 'Temp')
-	if defined $ENV{windir};
+    return File::Spec->catfile($ENV{windir}, 'Temp')    if defined $ENV{windir};
 
     return 'C:\Temp';
 }
@@ -56,35 +58,33 @@ sub system_temp {
 sub _var_dir {
     my ($class, $name, $more_name, $scope)=@_;
     if ($scope eq 'user') {
-	File::Spec->catdir($class->app_user_dir($name), $name, 'Data', $more_name)
-    }
-    else {
-	File::Spec->catdir($class->app_dir($name), 'Data', $more_name);
+        File::Spec->catdir($class->app_user_dir($name), $name, 'Data', $more_name)
+    } else {
+        File::Spec->catdir($class->app_dir($name), 'Data', $more_name);
     }
 }
 
 sub _bin_dir {
     my ($class, $name, $more_name, $scope)=@_;
     if ($scope eq 'app') {
-	$class->app_dir($name);
-    }
-    else {
-	die "unimplemented option scope => $scope";
+        $class->app_dir($name);
+    } else {
+        die "unimplemented option scope => $scope";
     }
 }
 
 sub look_for_helper {
-
     my ($class, $dir, $helper)=@_;
 
     my @ext=('', ( defined $ENV{PATHEXT}
-		   ? (split /;/, $ENV{PATHEXT})
-		   : qw(.COM .EXE .BAT .CMD)));
+           ? (split /;/, $ENV{PATHEXT})
+           : qw(.COM .EXE .BAT .CMD)));
 
     for my $ext (@ext) {
-	my $path=File::Spec->catfile($dir, $helper.$ext);
-	-e $path and -x $path and return $path;
+        my $path=File::Spec->catfile($dir, $helper.$ext);
+        -e $path and -x $path and return $path;
     }
+
     croak "helper '$helper' not found";
 }
 
@@ -92,64 +92,61 @@ sub look_for_file {
     my ($class, $name, $write, $global)=@_;
     my $fn;
     my $fnwe=$class->add_extension($name, 'cfg');
+    
     if ($write) {
-	if ($global) {
-	    return File::Spec->catfile($class->app_dir($name), $fnwe)
-	}
-	else {
-	    # my $login=getlogin();
-	    return File::Spec->catfile($class->app_user_dir($name),
-				       $fnwe );
-	}
+        return File::Spec->catfile($class->app_dir($name), $fnwe)   if ($global);
+        # my $login=getlogin();
+        return File::Spec->catfile($class->app_user_dir($name), $fnwe );
+
+    } else {
+        unless ($global) {
+            $fn=File::Spec->catfile($class->app_user_dir, $fnwe );
+            return $fn if -f $fn;
+        }
+
+        $fn=File::Spec->catfile($class->app_dir($name), $fnwe);
+        return $fn if -f $fn;
     }
-    else {
-	unless ($global) {
-	    $fn=File::Spec->catfile($class->app_user_dir, $fnwe );
-	    return $fn if -f $fn;
-	}
-	$fn=File::Spec->catfile($class->app_dir($name), $fnwe);
-	return $fn if -f $fn;
-    }
-    return undef;
+    
+    return;
 }
 
 sub look_for_dir_file {
     my ($class, $dir, $name, $write, $global)=@_;
     my $fn;
     my $fnwe=$class->add_extension($name, 'cfg');
+    
     if ($write) {
-	if ($global) {
-	    return File::Spec->catfile($class->app_dir($dir), $dir, $fnwe)
-	}
-	else {
-	    # my $login=getlogin();
-	    return File::Spec->catfile($class->app_user_dir($dir),
-				       $dir, $fnwe );
-	}
+        return File::Spec->catfile($class->app_dir($dir), $dir, $fnwe)  if ($global);
+
+        # my $login=getlogin();
+        return File::Spec->catfile($class->app_user_dir($dir), $dir, $fnwe );
+
+    } else {
+        unless ($global) {
+            $fn=File::Spec->catfile($class->app_user_dir($name), $dir, $fnwe );
+            return $fn if -f $fn;
+        }
+        $fn=File::Spec->catfile($class->app_dir($name), $fnwe);
+        return $fn if -f $fn;
     }
-    else {
-	unless ($global) {
-	    $fn=File::Spec->catfile($class->app_user_dir($name),
-				    $dir, $fnwe );
-	    return $fn if -f $fn;
-	}
-	$fn=File::Spec->catfile($class->app_dir($name),
-				$fnwe);
-	return $fn if -f $fn;
-    }
-    return undef;
+
+    return;
 }
 
 1;
+
 __END__
 
+=encoding utf-8
+
 =head1 NAME
 
 Config::Find::WinAny - Behaviours common to any Win32 OS for Config::Find
 
 =head1 SYNOPSIS
 
-  # don't use Config::Find::WinAny;
+  # don't use Config::Find::WinAny directly
   use Config::Find;
 
 =head1 ABSTRACT
@@ -193,11 +190,12 @@ configuration data under ${LOCAL_APPDATA} as returned by
 C<Win32::GetFolderPath(CSIDL_LOCAL_APPDATA)> (if this call fails, the
 old approach is used).  Also, global configuration files were stored
 under a new directory placed in the same dir as the script but this is
-unnecesary because windows apps already go in its own directory.
+unnecesary because windows apps already go in their own directory.
 
-=head2 EXPORT
-
-None by default.
+It seems that, sometimes, ${LOCAL_APPDATA} points to the user desktop
+and placing configuration files there would be obviusly wrong. As a
+work around, the module will ignore ${LOCAL_APPDATA} or ${APPDATA} if
+they point to any place below the desktop path.
 
 =head1 SEE ALSO
 
@@ -205,11 +203,11 @@ L<Config::Find>, L<Config::Find::Any>
 
 =head1 AUTHOR
 
-Salvador Fandio, E<lt>sfandino@yahoo.comE<gt>
+Salvador Fandio Garca, E<lt>sfandino@yahoo.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003 by Salvador Fandio
+Copyright 2003-2015 by Salvador Fandio Garca (sfandino@yahoo.com)
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
