@@ -1,6 +1,6 @@
 package Config::Find::WinCE;
 
-our $VERSION = '0.01';
+our $VERSION = '0.27';
 
 use strict;
 use warnings;
@@ -10,15 +10,18 @@ use Config::Find::WinAny
 our @ISA = qw(Config::Find::WinAny);
 
 1;
+
 __END__
 
+=encoding utf-8
+
 =head1 NAME
 
 Config::Find::WinCE - WinCE idiosyncrasies for Config::Find
 
 =head1 SYNOPSIS
 
-  # don't use Config::Find::WinCE;
+  # don't use Config::Find::WinCE directly
   use Config::Find;
 
 =head1 ABSTRACT
@@ -27,14 +30,8 @@ Implements WinCE specific features for Config::Find
 
 =head1 DESCRIPTION
 
-Stub documentation for Config::Find::WinCE, created by h2xs.
-
-
-=head2 EXPORT
-
-None by default.
-
-
+Contains any idiosyncrasies found within WinCE, that do not apply to the 
+standard Win32 base.
 
 =head1 SEE ALSO
 
@@ -42,11 +39,11 @@ L<Config::Find>, L<Config::Find::WinAny>, L<Config::Find::Any>
 
 =head1 AUTHOR
 
-Salvador Fandio, E<lt>sfandino@yahoo.comE<gt>
+Salvador Fandio Garca, E<lt>sfandino@yahoo.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003 by Salvador Fandio
+Copyright 2003-2015 by Salvador Fandio Garca (sfandino@yahoo.com)
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
